/*-GNU-GPL-BEGIN-*
nepim - network pipemeter
Copyright (C) 2005 Everton da Silva Marques

nepim is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

nepim is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with nepim; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.
*-GNU-GPL-END-*/


#include "conf.h"

nepim_global_t nepim_global = {
  0,      /* prog_name */
  0,      /* hostname */
  0,      /* client_mode */
  0,      /* udp_mode */
  0,      /* duplex_mode */
  1,      /* pipes */
  -1,     /* bit_rate */
  2,      /* stat_interval */
  10,     /* test_duration */
  32768,  /* tcp_write_size */
  32768,  /* tcp_read_size */
  4096,   /* udp_write_size */
  4096,   /* udp_read_size */
  1234,   /* port */
  0,      /* no_inet6 */
  250000, /* write_delay (usec, bit_rate > 0) */

  0, /* oop source */
  0  /* source interface */
};

